@@ -18,8 +18,11 @@
 # ---------------------------------------------------------------------------- #
 # ############################################################################ #
 
-from .qt_colored_logger import LoggerQ, PickerModifierQ
+from .color_picker import HexColor, DecColor, CodColor
+from .exceptions import ColorException
+from .colored_logger import HtmlColorSetInit, Logger
+from .html_colored_logger import HtmlColorSetInitQ, LoggerQ
 
 __authot__ = "Kalynovsky 'Nakama3942' Valentin"
-__version__ = "0.0.5"
+__version__ = "0.0.8"
 __email__ = "nakama3942@gmail.com"
\ No newline at end of file
